Low-level bit readers and writers plus shared entropy coders — Asymmetric Numeral Systems (ANS), arithmetic coding, and Huffman coding — required by AV1, AV2, and JPEG XL.
Placeholder — implementation pending.
Low-level bit readers and writers plus shared entropy coders — Asymmetric Numeral Systems (ANS), arithmetic coding, and Huffman coding — required by AV1, AV2, and JPEG XL.
Placeholder — implementation pending.